<a name="aea.test_tools.exceptions"></a>
# aea.test`_`tools.exceptions

Module with AEA testing exceptions.

<a name="aea.test_tools.exceptions.AEATestingException"></a>
## AEATestingException Objects

```python
class AEATestingException(Exception)
```

An exception to be raised on incorrect testing tools usage.

